<?php

return [
    'Names' => [
        'af' => 'африканс',
        'af_NA' => 'африканс (Намибија)',
        'af_ZA' => 'африканс (Јужноафриканска Република)',
        'ak' => 'акански',
        'ak_GH' => 'акански (Гана)',
        'am' => 'амхарски',
        'am_ET' => 'амхарски (Етиопија)',
        'ar' => 'арапски',
        'ar_001' => 'арапски (Свет)',
        'ar_AE' => 'арапски (Обединети Арапски Емирати)',
        'ar_BH' => 'арапски (Бахреин)',
        'ar_DJ' => 'арапски (Џибути)',
        'ar_DZ' => 'арапски (Алжир)',
        'ar_EG' => 'арапски (Египет)',
        'ar_EH' => 'арапски (Западна Сахара)',
        'ar_ER' => 'арапски (Еритреја)',
        'ar_IL' => 'арапски (Израел)',
        'ar_IQ' => 'арапски (Ирак)',
        'ar_JO' => 'арапски (Јордан)',
        'ar_KM' => 'арапски (Коморски Острови)',
        'ar_KW' => 'арапски (Кувајт)',
        'ar_LB' => 'арапски (Либан)',
        'ar_LY' => 'арапски (Либија)',
        'ar_MA' => 'арапски (Мароко)',
        'ar_MR' => 'арапски (Мавританија)',
        'ar_OM' => 'арапски (Оман)',
        'ar_PS' => 'арапски (Палестински Територии)',
        'ar_QA' => 'арапски (Катар)',
        'ar_SA' => 'арапски (Саудиска Арабија)',
        'ar_SD' => 'арапски (Судан)',
        'ar_SO' => 'арапски (Сомалија)',
        'ar_SS' => 'арапски (Јужен Судан)',
        'ar_SY' => 'арапски (Сирија)',
        'ar_TD' => 'арапски (Чад)',
        'ar_TN' => 'арапски (Тунис)',
        'ar_YE' => 'арапски (Јемен)',
        'as' => 'асамски',
        'as_IN' => 'асамски (Индија)',
        'az' => 'азербејџански',
        'az_AZ' => 'азербејџански (Азербејџан)',
        'az_Cyrl' => 'азербејџански (кирилско писмо)',
        'az_Cyrl_AZ' => 'азербејџански (кирилско писмо, Азербејџан)',
        'az_Latn' => 'азербејџански (латинично писмо)',
        'az_Latn_AZ' => 'азербејџански (латинично писмо, Азербејџан)',
        'be' => 'белоруски',
        'be_BY' => 'белоруски (Белорусија)',
        'bg' => 'бугарски',
        'bg_BG' => 'бугарски (Бугарија)',
        'bm' => 'бамбара',
        'bm_ML' => 'бамбара (Мали)',
        'bn' => 'бенгалски',
        'bn_BD' => 'бенгалски (Бангладеш)',
        'bn_IN' => 'бенгалски (Индија)',
        'bo' => 'тибетски',
        'bo_CN' => 'тибетски (Кина)',
        'bo_IN' => 'тибетски (Индија)',
        'br' => 'бретонски',
        'br_FR' => 'бретонски (Франција)',
        'bs' => 'босански',
        'bs_BA' => 'босански (Босна и Херцеговина)',
        'bs_Cyrl' => 'босански (кирилско писмо)',
        'bs_Cyrl_BA' => 'босански (кирилско писмо, Босна и Херцеговина)',
        'bs_Latn' => 'босански (латинично писмо)',
        'bs_Latn_BA' => 'босански (латинично писмо, Босна и Херцеговина)',
        'ca' => 'каталонски',
        'ca_AD' => 'каталонски (Андора)',
        'ca_ES' => 'каталонски (Шпанија)',
        'ca_FR' => 'каталонски (Франција)',
        'ca_IT' => 'каталонски (Италија)',
        'ce' => 'чеченски',
        'ce_RU' => 'чеченски (Русија)',
        'cs' => 'чешки',
        'cs_CZ' => 'чешки (Чешка)',
        'cv' => 'чувашки',
        'cv_RU' => 'чувашки (Русија)',
        'cy' => 'велшки',
        'cy_GB' => 'велшки (Обединето Кралство)',
        'da' => 'дански',
        'da_DK' => 'дански (Данска)',
        'da_GL' => 'дански (Гренланд)',
        'de' => 'германски',
        'de_AT' => 'германски (Австрија)',
        'de_BE' => 'германски (Белгија)',
        'de_CH' => 'германски (Швајцарија)',
        'de_DE' => 'германски (Германија)',
        'de_IT' => 'германски (Италија)',
        'de_LI' => 'германски (Лихтенштајн)',
        'de_LU' => 'германски (Луксембург)',
        'dz' => 'ѕонгка',
        'dz_BT' => 'ѕонгка (Бутан)',
        'ee' => 'еве',
        'ee_GH' => 'еве (Гана)',
        'ee_TG' => 'еве (Того)',
        'el' => 'грчки',
        'el_CY' => 'грчки (Кипар)',
        'el_GR' => 'грчки (Грција)',
        'en' => 'англиски',
        'en_001' => 'англиски (Свет)',
        'en_150' => 'англиски (Европа)',
        'en_AE' => 'англиски (Обединети Арапски Емирати)',
        'en_AG' => 'англиски (Антига и Барбуда)',
        'en_AI' => 'англиски (Ангвила)',
        'en_AS' => 'англиски (Американска Самоа)',
        'en_AT' => 'англиски (Австрија)',
        'en_AU' => 'англиски (Австралија)',
        'en_BB' => 'англиски (Барбадос)',
        'en_BE' => 'англиски (Белгија)',
        'en_BI' => 'англиски (Бурунди)',
        'en_BM' => 'англиски (Бермуди)',
        'en_BS' => 'англиски (Бахами)',
        'en_BW' => 'англиски (Боцвана)',
        'en_BZ' => 'англиски (Белизе)',
        'en_CA' => 'англиски (Канада)',
        'en_CC' => 'англиски (Кокосови [Килиншки] Острови)',
        'en_CH' => 'англиски (Швајцарија)',
        'en_CK' => 'англиски (Кукови Острови)',
        'en_CM' => 'англиски (Камерун)',
        'en_CX' => 'англиски (Божиќен Остров)',
        'en_CY' => 'англиски (Кипар)',
        'en_DE' => 'англиски (Германија)',
        'en_DK' => 'англиски (Данска)',
        'en_DM' => 'англиски (Доминика)',
        'en_ER' => 'англиски (Еритреја)',
        'en_FI' => 'англиски (Финска)',
        'en_FJ' => 'англиски (Фиџи)',
        'en_FK' => 'англиски (Фолкландски Острови)',
        'en_FM' => 'англиски (Микронезија)',
        'en_GB' => 'англиски (Обединето Кралство)',
        'en_GD' => 'англиски (Гренада)',
        'en_GG' => 'англиски (Гернзи)',
        'en_GH' => 'англиски (Гана)',
        'en_GI' => 'англиски (Гибралтар)',
        'en_GM' => 'англиски (Гамбија)',
        'en_GU' => 'англиски (Гуам)',
        'en_GY' => 'англиски (Гвајана)',
        'en_HK' => 'англиски (Хонгконг САР Кина)',
        'en_IE' => 'англиски (Ирска)',
        'en_IL' => 'англиски (Израел)',
        'en_IM' => 'англиски (Остров Ман)',
        'en_IN' => 'англиски (Индија)',
        'en_IO' => 'англиски (Британска Индоокеанска Територија)',
        'en_JE' => 'англиски (Џерси)',
        'en_JM' => 'англиски (Јамајка)',
        'en_KE' => 'англиски (Кенија)',
        'en_KI' => 'англиски (Кирибати)',
        'en_KN' => 'англиски (Свети Китс и Невис)',
        'en_KY' => 'англиски (Кајмански Острови)',
        'en_LC' => 'англиски (Сент Лусија)',
        'en_LR' => 'англиски (Либерија)',
        'en_LS' => 'англиски (Лесото)',
        'en_MG' => 'англиски (Мадагаскар)',
        'en_MH' => 'англиски (Маршалски Острови)',
        'en_MO' => 'англиски (Макао САР)',
        'en_MP' => 'англиски (Северни Маријански Острови)',
        'en_MS' => 'англиски (Монсерат)',
        'en_MT' => 'англиски (Малта)',
        'en_MU' => 'англиски (Маврициус)',
        'en_MV' => 'англиски (Малдиви)',
        'en_MW' => 'англиски (Малави)',
        'en_MY' => 'англиски (Малезија)',
        'en_NA' => 'англиски (Намибија)',
        'en_NF' => 'англиски (Норфолшки Остров)',
        'en_NG' => 'англиски (Нигерија)',
        'en_NL' => 'англиски (Холандија)',
        'en_NR' => 'англиски (Науру)',
        'en_NU' => 'англиски (Ниује)',
        'en_NZ' => 'англиски (Нов Зеланд)',
        'en_PG' => 'англиски (Папуа Нова Гвинеја)',
        'en_PH' => 'англиски (Филипини)',
        'en_PK' => 'англиски (Пакистан)',
        'en_PN' => 'англиски (Питкернски Острови)',
        'en_PR' => 'англиски (Порторико)',
        'en_PW' => 'англиски (Палау)',
        'en_RW' => 'англиски (Руанда)',
        'en_SB' => 'англиски (Соломонски Острови)',
        'en_SC' => 'англиски (Сејшели)',
        'en_SD' => 'англиски (Судан)',
        'en_SE' => 'англиски (Шведска)',
        'en_SG' => 'англиски (Сингапур)',
        'en_SH' => 'англиски (Света Елена)',
        'en_SI' => 'англиски (Словенија)',
        'en_SL' => 'англиски (Сиера Леоне)',
        'en_SS' => 'англиски (Јужен Судан)',
        'en_SX' => 'англиски (Свети Мартин)',
        'en_SZ' => 'англиски (Свазиленд)',
        'en_TC' => 'англиски (Острови Туркс и Каикос)',
        'en_TK' => 'англиски (Токелау)',
        'en_TO' => 'англиски (Тонга)',
        'en_TT' => 'англиски (Тринидад и Тобаго)',
        'en_TV' => 'англиски (Тувалу)',
        'en_TZ' => 'англиски (Танзанија)',
        'en_UG' => 'англиски (Уганда)',
        'en_UM' => 'англиски (Американски територии во Пацификот)',
        'en_US' => 'англиски (Соединети Американски Држави)',
        'en_VC' => 'англиски (Сент Винсент и Гренадини)',
        'en_VG' => 'англиски (Британски Девствени Острови)',
        'en_VI' => 'англиски (Американски Девствени Острови)',
        'en_VU' => 'англиски (Вануату)',
        'en_WS' => 'англиски (Самоа)',
        'en_ZA' => 'англиски (Јужноафриканска Република)',
        'en_ZM' => 'англиски (Замбија)',
        'en_ZW' => 'англиски (Зимбабве)',
        'eo' => 'есперанто',
        'eo_001' => 'есперанто (Свет)',
        'es' => 'шпански',
        'es_419' => 'шпански (Латинска Америка)',
        'es_AR' => 'шпански (Аргентина)',
        'es_BO' => 'шпански (Боливија)',
        'es_BR' => 'шпански (Бразил)',
        'es_BZ' => 'шпански (Белизе)',
        'es_CL' => 'шпански (Чиле)',
        'es_CO' => 'шпански (Колумбија)',
        'es_CR' => 'шпански (Костарика)',
        'es_CU' => 'шпански (Куба)',
        'es_DO' => 'шпански (Доминиканска Република)',
        'es_EC' => 'шпански (Еквадор)',
        'es_ES' => 'шпански (Шпанија)',
        'es_GQ' => 'шпански (Екваторска Гвинеја)',
        'es_GT' => 'шпански (Гватемала)',
        'es_HN' => 'шпански (Хондурас)',
        'es_MX' => 'шпански (Мексико)',
        'es_NI' => 'шпански (Никарагва)',
        'es_PA' => 'шпански (Панама)',
        'es_PE' => 'шпански (Перу)',
        'es_PH' => 'шпански (Филипини)',
        'es_PR' => 'шпански (Порторико)',
        'es_PY' => 'шпански (Парагвај)',
        'es_SV' => 'шпански (Ел Салвадор)',
        'es_US' => 'шпански (Соединети Американски Држави)',
        'es_UY' => 'шпански (Уругвај)',
        'es_VE' => 'шпански (Венецуела)',
        'et' => 'естонски',
        'et_EE' => 'естонски (Естонија)',
        'eu' => 'баскиски',
        'eu_ES' => 'баскиски (Шпанија)',
        'fa' => 'персиски',
        'fa_AF' => 'персиски (Авганистан)',
        'fa_IR' => 'персиски (Иран)',
        'ff' => 'фула',
        'ff_Adlm' => 'фула (адламско)',
        'ff_Adlm_BF' => 'фула (адламско, Буркина Фасо)',
        'ff_Adlm_CM' => 'фула (адламско, Камерун)',
        'ff_Adlm_GH' => 'фула (адламско, Гана)',
        'ff_Adlm_GM' => 'фула (адламско, Гамбија)',
        'ff_Adlm_GN' => 'фула (адламско, Гвинеја)',
        'ff_Adlm_GW' => 'фула (адламско, Гвинеја Бисао)',
        'ff_Adlm_LR' => 'фула (адламско, Либерија)',
        'ff_Adlm_MR' => 'фула (адламско, Мавританија)',
        'ff_Adlm_NE' => 'фула (адламско, Нигер)',
        'ff_Adlm_NG' => 'фула (адламско, Нигерија)',
        'ff_Adlm_SL' => 'фула (адламско, Сиера Леоне)',
        'ff_Adlm_SN' => 'фула (адламско, Сенегал)',
        'ff_CM' => 'фула (Камерун)',
        'ff_GN' => 'фула (Гвинеја)',
        'ff_Latn' => 'фула (латинично писмо)',
        'ff_Latn_BF' => 'фула (латинично писмо, Буркина Фасо)',
        'ff_Latn_CM' => 'фула (латинично писмо, Камерун)',
        'ff_Latn_GH' => 'фула (латинично писмо, Гана)',
        'ff_Latn_GM' => 'фула (латинично писмо, Гамбија)',
        'ff_Latn_GN' => 'фула (латинично писмо, Гвинеја)',
        'ff_Latn_GW' => 'фула (латинично писмо, Гвинеја Бисао)',
        'ff_Latn_LR' => 'фула (латинично писмо, Либерија)',
        'ff_Latn_MR' => 'фула (латинично писмо, Мавританија)',
        'ff_Latn_NE' => 'фула (латинично писмо, Нигер)',
        'ff_Latn_NG' => 'фула (латинично писмо, Нигерија)',
        'ff_Latn_SL' => 'фула (латинично писмо, Сиера Леоне)',
        'ff_Latn_SN' => 'фула (латинично писмо, Сенегал)',
        'ff_MR' => 'фула (Мавританија)',
        'ff_SN' => 'фула (Сенегал)',
        'fi' => 'фински',
        'fi_FI' => 'фински (Финска)',
        'fo' => 'фарски',
        'fo_DK' => 'фарски (Данска)',
        'fo_FO' => 'фарски (Фарски Острови)',
        'fr' => 'француски',
        'fr_BE' => 'француски (Белгија)',
        'fr_BF' => 'француски (Буркина Фасо)',
        'fr_BI' => 'француски (Бурунди)',
        'fr_BJ' => 'француски (Бенин)',
        'fr_BL' => 'француски (Свети Вартоломеј)',
        'fr_CA' => 'француски (Канада)',
        'fr_CD' => 'француски (Конго - Киншаса)',
        'fr_CF' => 'француски (Централноафриканска Република)',
        'fr_CG' => 'француски (Конго - Бразавил)',
        'fr_CH' => 'француски (Швајцарија)',
        'fr_CI' => 'француски (Брегот на Слоновата Коска)',
        'fr_CM' => 'француски (Камерун)',
        'fr_DJ' => 'француски (Џибути)',
        'fr_DZ' => 'француски (Алжир)',
        'fr_FR' => 'француски (Франција)',
        'fr_GA' => 'француски (Габон)',
        'fr_GF' => 'француски (Француска Гвајана)',
        'fr_GN' => 'француски (Гвинеја)',
        'fr_GP' => 'француски (Гвадалупе)',
        'fr_GQ' => 'француски (Екваторска Гвинеја)',
        'fr_HT' => 'француски (Хаити)',
        'fr_KM' => 'француски (Коморски Острови)',
        'fr_LU' => 'француски (Луксембург)',
        'fr_MA' => 'француски (Мароко)',
        'fr_MC' => 'француски (Монако)',
        'fr_MF' => 'француски (Сент Мартин)',
        'fr_MG' => 'француски (Мадагаскар)',
        'fr_ML' => 'француски (Мали)',
        'fr_MQ' => 'француски (Мартиник)',
        'fr_MR' => 'француски (Мавританија)',
        'fr_MU' => 'француски (Маврициус)',
        'fr_NC' => 'француски (Нова Каледонија)',
        'fr_NE' => 'француски (Нигер)',
        'fr_PF' => 'француски (Француска Полинезија)',
        'fr_PM' => 'француски (Сент Пјер и Микелан)',
        'fr_RE' => 'француски (Рејунион)',
        'fr_RW' => 'француски (Руанда)',
        'fr_SC' => 'француски (Сејшели)',
        'fr_SN' => 'француски (Сенегал)',
        'fr_SY' => 'француски (Сирија)',
        'fr_TD' => 'француски (Чад)',
        'fr_TG' => 'француски (Того)',
        'fr_TN' => 'француски (Тунис)',
        'fr_VU' => 'француски (Вануату)',
        'fr_WF' => 'француски (Валис и Футуна)',
        'fr_YT' => 'француски (Мајот)',
        'fy' => 'западнофризиски',
        'fy_NL' => 'западнофризиски (Холандија)',
        'ga' => 'ирски',
        'ga_GB' => 'ирски (Обединето Кралство)',
        'ga_IE' => 'ирски (Ирска)',
        'gd' => 'шкотски гелски',
        'gd_GB' => 'шкотски гелски (Обединето Кралство)',
        'gl' => 'галициски',
        'gl_ES' => 'галициски (Шпанија)',
        'gu' => 'гуџарати',
        'gu_IN' => 'гуџарати (Индија)',
        'gv' => 'манкс',
        'gv_IM' => 'манкс (Остров Ман)',
        'ha' => 'хауса',
        'ha_GH' => 'хауса (Гана)',
        'ha_NE' => 'хауса (Нигер)',
        'ha_NG' => 'хауса (Нигерија)',
        'he' => 'хебрејски',
        'he_IL' => 'хебрејски (Израел)',
        'hi' => 'хинди',
        'hi_IN' => 'хинди (Индија)',
        'hi_Latn' => 'хинди (латинично писмо)',
        'hi_Latn_IN' => 'хинди (латинично писмо, Индија)',
        'hr' => 'хрватски',
        'hr_BA' => 'хрватски (Босна и Херцеговина)',
        'hr_HR' => 'хрватски (Хрватска)',
        'hu' => 'унгарски',
        'hu_HU' => 'унгарски (Унгарија)',
        'hy' => 'ерменски',
        'hy_AM' => 'ерменски (Ерменија)',
        'ia' => 'интерлингва',
        'ia_001' => 'интерлингва (Свет)',
        'id' => 'индонезиски',
        'id_ID' => 'индонезиски (Индонезија)',
        'ig' => 'игбо',
        'ig_NG' => 'игбо (Нигерија)',
        'ii' => 'сичуан ји',
        'ii_CN' => 'сичуан ји (Кина)',
        'is' => 'исландски',
        'is_IS' => 'исландски (Исланд)',
        'it' => 'италијански',
        'it_CH' => 'италијански (Швајцарија)',
        'it_IT' => 'италијански (Италија)',
        'it_SM' => 'италијански (Сан Марино)',
        'it_VA' => 'италијански (Ватикан)',
        'ja' => 'јапонски',
        'ja_JP' => 'јапонски (Јапонија)',
        'jv' => 'јавански',
        'jv_ID' => 'јавански (Индонезија)',
        'ka' => 'грузиски',
        'ka_GE' => 'грузиски (Грузија)',
        'ki' => 'кикују',
        'ki_KE' => 'кикују (Кенија)',
        'kk' => 'казашки',
        'kk_KZ' => 'казашки (Казахстан)',
        'kl' => 'калалисут',
        'kl_GL' => 'калалисут (Гренланд)',
        'km' => 'кмерски',
        'km_KH' => 'кмерски (Камбоџа)',
        'kn' => 'каннада',
        'kn_IN' => 'каннада (Индија)',
        'ko' => 'корејски',
        'ko_KP' => 'корејски (Северна Кореја)',
        'ko_KR' => 'корејски (Јужна Кореја)',
        'ks' => 'кашмирски',
        'ks_Arab' => 'кашмирски (арапско писмо)',
        'ks_Arab_IN' => 'кашмирски (арапско писмо, Индија)',
        'ks_Deva' => 'кашмирски (деванагари)',
        'ks_Deva_IN' => 'кашмирски (деванагари, Индија)',
        'ks_IN' => 'кашмирски (Индија)',
        'ku' => 'курдски',
        'ku_TR' => 'курдски (Турција)',
        'kw' => 'корнски',
        'kw_GB' => 'корнски (Обединето Кралство)',
        'ky' => 'киргиски',
        'ky_KG' => 'киргиски (Киргистан)',
        'lb' => 'луксембуршки',
        'lb_LU' => 'луксембуршки (Луксембург)',
        'lg' => 'ганда',
        'lg_UG' => 'ганда (Уганда)',
        'ln' => 'лингала',
        'ln_AO' => 'лингала (Ангола)',
        'ln_CD' => 'лингала (Конго - Киншаса)',
        'ln_CF' => 'лингала (Централноафриканска Република)',
        'ln_CG' => 'лингала (Конго - Бразавил)',
        'lo' => 'лаошки',
        'lo_LA' => 'лаошки (Лаос)',
        'lt' => 'литвански',
        'lt_LT' => 'литвански (Литванија)',
        'lu' => 'луба-катанга',
        'lu_CD' => 'луба-катанга (Конго - Киншаса)',
        'lv' => 'латвиски',
        'lv_LV' => 'латвиски (Латвија)',
        'mg' => 'малгашки',
        'mg_MG' => 'малгашки (Мадагаскар)',
        'mi' => 'маорски',
        'mi_NZ' => 'маорски (Нов Зеланд)',
        'mk' => 'македонски',
        'mk_MK' => 'македонски (Северна Македонија)',
        'ml' => 'малајалски',
        'ml_IN' => 'малајалски (Индија)',
        'mn' => 'монголски',
        'mn_MN' => 'монголски (Монголија)',
        'mr' => 'марати',
        'mr_IN' => 'марати (Индија)',
        'ms' => 'малајски',
        'ms_BN' => 'малајски (Брунеј)',
        'ms_ID' => 'малајски (Индонезија)',
        'ms_MY' => 'малајски (Малезија)',
        'ms_SG' => 'малајски (Сингапур)',
        'mt' => 'малтешки',
        'mt_MT' => 'малтешки (Малта)',
        'my' => 'бурмански',
        'my_MM' => 'бурмански (Мјанмар [Бурма])',
        'nb' => 'норвешки букмол',
        'nb_NO' => 'норвешки букмол (Норвешка)',
        'nb_SJ' => 'норвешки букмол (Свалбард и Јан Мајен)',
        'nd' => 'северен ндебеле',
        'nd_ZW' => 'северен ндебеле (Зимбабве)',
        'ne' => 'непалски',
        'ne_IN' => 'непалски (Индија)',
        'ne_NP' => 'непалски (Непал)',
        'nl' => 'холандски',
        'nl_AW' => 'холандски (Аруба)',
        'nl_BE' => 'холандски (Белгија)',
        'nl_BQ' => 'холандски (Карипска Холандија)',
        'nl_CW' => 'холандски (Курасао)',
        'nl_NL' => 'холандски (Холандија)',
        'nl_SR' => 'холандски (Суринам)',
        'nl_SX' => 'холандски (Свети Мартин)',
        'nn' => 'норвешки нинорск',
        'nn_NO' => 'норвешки нинорск (Норвешка)',
        'no' => 'норвешки',
        'no_NO' => 'норвешки (Норвешка)',
        'om' => 'оромо',
        'om_ET' => 'оромо (Етиопија)',
        'om_KE' => 'оромо (Кенија)',
        'or' => 'одија',
        'or_IN' => 'одија (Индија)',
        'os' => 'осетски',
        'os_GE' => 'осетски (Грузија)',
        'os_RU' => 'осетски (Русија)',
        'pa' => 'пенџапски',
        'pa_Arab' => 'пенџапски (арапско писмо)',
        'pa_Arab_PK' => 'пенџапски (арапско писмо, Пакистан)',
        'pa_Guru' => 'пенџапски (гурмуки)',
        'pa_Guru_IN' => 'пенџапски (гурмуки, Индија)',
        'pa_IN' => 'пенџапски (Индија)',
        'pa_PK' => 'пенџапски (Пакистан)',
        'pl' => 'полски',
        'pl_PL' => 'полски (Полска)',
        'ps' => 'паштунски',
        'ps_AF' => 'паштунски (Авганистан)',
        'ps_PK' => 'паштунски (Пакистан)',
        'pt' => 'португалски',
        'pt_AO' => 'португалски (Ангола)',
        'pt_BR' => 'португалски (Бразил)',
        'pt_CH' => 'португалски (Швајцарија)',
        'pt_CV' => 'португалски (Кабо Верде)',
        'pt_GQ' => 'португалски (Екваторска Гвинеја)',
        'pt_GW' => 'португалски (Гвинеја Бисао)',
        'pt_LU' => 'португалски (Луксембург)',
        'pt_MO' => 'португалски (Макао САР)',
        'pt_MZ' => 'португалски (Мозамбик)',
        'pt_PT' => 'португалски (Португалија)',
        'pt_ST' => 'португалски (Саун Томе и Принсип)',
        'pt_TL' => 'португалски (Тимор Лесте)',
        'qu' => 'кечуански',
        'qu_BO' => 'кечуански (Боливија)',
        'qu_EC' => 'кечуански (Еквадор)',
        'qu_PE' => 'кечуански (Перу)',
        'rm' => 'реторомански',
        'rm_CH' => 'реторомански (Швајцарија)',
        'rn' => 'рунди',
        'rn_BI' => 'рунди (Бурунди)',
        'ro' => 'романски',
        'ro_MD' => 'романски (Молдавија)',
        'ro_RO' => 'романски (Романија)',
        'ru' => 'руски',
        'ru_BY' => 'руски (Белорусија)',
        'ru_KG' => 'руски (Киргистан)',
        'ru_KZ' => 'руски (Казахстан)',
        'ru_MD' => 'руски (Молдавија)',
        'ru_RU' => 'руски (Русија)',
        'ru_UA' => 'руски (Украина)',
        'rw' => 'руандски',
        'rw_RW' => 'руандски (Руанда)',
        'sa' => 'санскрит',
        'sa_IN' => 'санскрит (Индија)',
        'sc' => 'сардински',
        'sc_IT' => 'сардински (Италија)',
        'sd' => 'синди',
        'sd_Arab' => 'синди (арапско писмо)',
        'sd_Arab_PK' => 'синди (арапско писмо, Пакистан)',
        'sd_Deva' => 'синди (деванагари)',
        'sd_Deva_IN' => 'синди (деванагари, Индија)',
        'sd_IN' => 'синди (Индија)',
        'sd_PK' => 'синди (Пакистан)',
        'se' => 'северен сами',
        'se_FI' => 'северен сами (Финска)',
        'se_NO' => 'северен сами (Норвешка)',
        'se_SE' => 'северен сами (Шведска)',
        'sg' => 'санго',
        'sg_CF' => 'санго (Централноафриканска Република)',
        'sh' => 'српскохрватски',
        'sh_BA' => 'српскохрватски (Босна и Херцеговина)',
        'si' => 'синхалски',
        'si_LK' => 'синхалски (Шри Ланка)',
        'sk' => 'словачки',
        'sk_SK' => 'словачки (Словачка)',
        'sl' => 'словенечки',
        'sl_SI' => 'словенечки (Словенија)',
        'sn' => 'шона',
        'sn_ZW' => 'шона (Зимбабве)',
        'so' => 'сомалиски',
        'so_DJ' => 'сомалиски (Џибути)',
        'so_ET' => 'сомалиски (Етиопија)',
        'so_KE' => 'сомалиски (Кенија)',
        'so_SO' => 'сомалиски (Сомалија)',
        'sq' => 'албански',
        'sq_AL' => 'албански (Албанија)',
        'sq_MK' => 'албански (Северна Македонија)',
        'sr' => 'српски',
        'sr_BA' => 'српски (Босна и Херцеговина)',
        'sr_Cyrl' => 'српски (кирилско писмо)',
        'sr_Cyrl_BA' => 'српски (кирилско писмо, Босна и Херцеговина)',
        'sr_Cyrl_ME' => 'српски (кирилско писмо, Црна Гора)',
        'sr_Cyrl_RS' => 'српски (кирилско писмо, Србија)',
        'sr_Latn' => 'српски (латинично писмо)',
        'sr_Latn_BA' => 'српски (латинично писмо, Босна и Херцеговина)',
        'sr_Latn_ME' => 'српски (латинично писмо, Црна Гора)',
        'sr_Latn_RS' => 'српски (латинично писмо, Србија)',
        'sr_ME' => 'српски (Црна Гора)',
        'sr_RS' => 'српски (Србија)',
        'su' => 'сундски',
        'su_ID' => 'сундски (Индонезија)',
        'su_Latn' => 'сундски (латинично писмо)',
        'su_Latn_ID' => 'сундски (латинично писмо, Индонезија)',
        'sv' => 'шведски',
        'sv_AX' => 'шведски (Оландски Острови)',
        'sv_FI' => 'шведски (Финска)',
        'sv_SE' => 'шведски (Шведска)',
        'sw' => 'свахили',
        'sw_CD' => 'свахили (Конго - Киншаса)',
        'sw_KE' => 'свахили (Кенија)',
        'sw_TZ' => 'свахили (Танзанија)',
        'sw_UG' => 'свахили (Уганда)',
        'ta' => 'тамилски',
        'ta_IN' => 'тамилски (Индија)',
        'ta_LK' => 'тамилски (Шри Ланка)',
        'ta_MY' => 'тамилски (Малезија)',
        'ta_SG' => 'тамилски (Сингапур)',
        'te' => 'телугу',
        'te_IN' => 'телугу (Индија)',
        'tg' => 'таџикистански',
        'tg_TJ' => 'таџикистански (Таџикистан)',
        'th' => 'тајландски',
        'th_TH' => 'тајландски (Тајланд)',
        'ti' => 'тигриња',
        'ti_ER' => 'тигриња (Еритреја)',
        'ti_ET' => 'тигриња (Етиопија)',
        'tk' => 'туркменски',
        'tk_TM' => 'туркменски (Туркменистан)',
        'tl' => 'тагалог',
        'tl_PH' => 'тагалог (Филипини)',
        'to' => 'тонгајски',
        'to_TO' => 'тонгајски (Тонга)',
        'tr' => 'турски',
        'tr_CY' => 'турски (Кипар)',
        'tr_TR' => 'турски (Турција)',
        'tt' => 'татарски',
        'tt_RU' => 'татарски (Русија)',
        'ug' => 'ујгурски',
        'ug_CN' => 'ујгурски (Кина)',
        'uk' => 'украински',
        'uk_UA' => 'украински (Украина)',
        'ur' => 'урду',
        'ur_IN' => 'урду (Индија)',
        'ur_PK' => 'урду (Пакистан)',
        'uz' => 'узбечки',
        'uz_AF' => 'узбечки (Авганистан)',
        'uz_Arab' => 'узбечки (арапско писмо)',
        'uz_Arab_AF' => 'узбечки (арапско писмо, Авганистан)',
        'uz_Cyrl' => 'узбечки (кирилско писмо)',
        'uz_Cyrl_UZ' => 'узбечки (кирилско писмо, Узбекистан)',
        'uz_Latn' => 'узбечки (латинично писмо)',
        'uz_Latn_UZ' => 'узбечки (латинично писмо, Узбекистан)',
        'uz_UZ' => 'узбечки (Узбекистан)',
        'vi' => 'виетнамски',
        'vi_VN' => 'виетнамски (Виетнам)',
        'wo' => 'волофски',
        'wo_SN' => 'волофски (Сенегал)',
        'xh' => 'коса',
        'xh_ZA' => 'коса (Јужноафриканска Република)',
        'yi' => 'јидиш',
        'yi_001' => 'јидиш (Свет)',
        'yo' => 'јорупски',
        'yo_BJ' => 'јорупски (Бенин)',
        'yo_NG' => 'јорупски (Нигерија)',
        'zh' => 'кинески',
        'zh_CN' => 'кинески (Кина)',
        'zh_HK' => 'кинески (Хонгконг САР Кина)',
        'zh_Hans' => 'кинески (поедноставено)',
        'zh_Hans_CN' => 'кинески (поедноставено, Кина)',
        'zh_Hans_HK' => 'кинески (поедноставено, Хонгконг САР Кина)',
        'zh_Hans_MO' => 'кинески (поедноставено, Макао САР)',
        'zh_Hans_SG' => 'кинески (поедноставено, Сингапур)',
        'zh_Hant' => 'кинески (традиционално)',
        'zh_Hant_HK' => 'кинески (традиционално, Хонгконг САР Кина)',
        'zh_Hant_MO' => 'кинески (традиционално, Макао САР)',
        'zh_Hant_TW' => 'кинески (традиционално, Тајван)',
        'zh_MO' => 'кинески (Макао САР)',
        'zh_SG' => 'кинески (Сингапур)',
        'zh_TW' => 'кинески (Тајван)',
        'zu' => 'зулу',
        'zu_ZA' => 'зулу (Јужноафриканска Република)',
    ],
];
